# Whip validator report

Date: 2018-08-20 09:43

## Summary

Total rows: 46834

#### Unknown fields:

(these fields are described in the whip specifications, but are missing in the data)

behavior eventID georeferenceRemarks license occurrenceRemarks organismQuantity organismQuantityType stateProvince verbatimCoordinates verbatimCoordinateSystem verbatimLatitude verbatimLongitude verbatimSRS vernacularName

#### Unspecified fields:

(these fields exist in data, but have no whip specification):

catalogNumber dataGeneralizations modified ownerInstitutionCode

#### General warnings:

- Following fields mentioned inside if specifications do not exist inside the document: 'organismQuantityType, verbatimCoordinateSystem, organismQuantity'

## Specifications

Field | Specification | Constraint | Passed records |
--- | --- | --- | --- | ---
| allowed | http://www.inbo.be/en/norms-for-data-use | 46834 |
| empty | False | 46834 |
| allowed | HumanObservation, PreservedSpecimen | 2134 |
Value issue samples:
| Data value | Message | # Rows failed | First presence row index
--- | --- | --- | --- | ---
1 | humanObservation | unallowed value humanObservation | 34675 | 4
2 | preservedSpecimen | unallowed value preservedSpecimen | 10025 | 1
| allowed_if_1 | PreservedSpecimen | 37806 |
Value issue samples:
| Data value | Message | # Rows failed | First presence row index
--- | --- | --- | --- | ---
1 | preservedSpecimen | unallowed value preservedSpecimen | 8755 | 1
2 | humanObservation | unallowed value humanObservation | 273 | 4
| empty | False | 46834 |
| empty_if_1 | False | 46834 |
| allowed | stridulation post | 46834 |
| empty | True | 46834 |
| allowed | Insecta | 46834 |
| empty | False | 46834 |
| allowed | Boosten, Carpentier, COL. SLABBAERT HOGE VENEN, collectie Stijn Vanacker, Decleer Kris, Devriese Rik, FSAG, Haghebaert, Hofmans Kurt, Inst. V. Beneden, KBIN, Keppens, Lebrun M., Mal, Université de Liège, Université de Mons, Universiteit Gent, V.V.E., W | 46834 |
| empty | True | 46834 |
| allowed | Europe | 46834 |
| empty | False | 46834 |
| allowed_if_1 | 707 | 46834 |
| allowed_if_2 | 3536 | 46834 |
| allowed_if_3 | 30 | 46834 |
| allowed_if_4 |  | 46834 |
| empty | True | 46834 |
| empty_if_1 | False | 46834 |
| empty_if_2 | False | 46834 |
| empty_if_3 | False | 46834 |
| empty_if_4 | True | 46834 |
| numberformat_if_1 | x | 46834 |
| numberformat_if_2 | x | 46834 |
| numberformat_if_3 | x | 46834 |
| allowed | BE | 46834 |
| empty | False | 46834 |
| allowed | https://doi.org/10.15468/1rcpsq | 0 |
Value issue samples:
| Data value | Message | # Rows failed | First presence row index
--- | --- | --- | --- | ---
1 | http://dataset.inbo.be/saltabel-occurrences | unallowed value http://dataset.inbo.be/saltabel-occurrences | 46834 | 1
| empty | False | 46834 |
| allowed | Saltabel - Orthoptera in Belgium | 46834 |
| empty | False | 46834 |
| empty | False | 46834 |
| max | 51.51 | 46834 |
| min | 49.49 | 46834 |
| numberformat | .5 | 46834 |
| empty | False | 46834 |
| max | 6.41 | 46834 |
| min | 2.53 | 46834 |
| numberformat | .5 | 46834 |
| dateformat | %Y-%m-%d, %Y-%m, %Y | 46831 |
Value issue samples:
| Data value | Message | # Rows failed | First presence row index
--- | --- | --- | --- | ---
1 | Unknown | string format of value 'Unknown' not compliant with '['%Y-%m-%d', '%Y-%m', '%Y']' | 3 | 24238
| empty | False | 46834 |
| maxdate | 2013-06-18 | 46831 |
Value issue samples:
| Data value | Message | # Rows failed | First presence row index
--- | --- | --- | --- | ---
1 | Unknown | value 'Unknown' could not be interpreted as date or datetime | 3 | 24238
| mindate | 1800-01-01 | 46831 |
Value issue samples:
| Data value | Message | # Rows failed | First presence row index
--- | --- | --- | --- | ---
1 | Unknown | value 'Unknown' could not be interpreted as date or datetime | 3 | 24238
| empty | False | 46834 |
| allowed | WGS84 | 46834 |
| empty | False | 46834 |
| allowed_if_1 | coordinates are centroid of used grid square | 46834 |
| allowed_if_2 |  | 46834 |
| empty | True | 46834 |
| empty_if_1 | False | 46834 |
| empty_if_2 | True | 46834 |
| delimitedvalues |  | 46834 |
| empty | True | 46834 |
| empty | True | 46834 |
| max | 15000 | 46834 |
| min | 1 | 46834 |
| numberformat | x | 46834 |
| allowed | INBO | 46834 |
| empty | False | 46834 |
| allowed | Animalia | 46834 |
| empty | False | 46834 |
| allowed | en | 46834 |
| empty | False | 46834 |
| allowed | http://creativecommons.org/publicdomain/zero/1.0/ | 46834 |
| empty | False | 46834 |
| allowed_delimitedvalue | adult, juvenile | 45459 |
Value issue samples:
| Data value | Message | # Rows failed | First presence row index
--- | --- | --- | --- | ---
1 | juvenile: 1 | unallowed value juvenile: 1 | 894 | 22
2 | juvenile: 2 | unallowed value juvenile: 2 | 145 | 170
3 | juvenile: 3 | unallowed value juvenile: 3 | 55 | 27
4 | Zangpost: 1 | unallowed value Zangpost: 1 | 50 | 2475
5 | juvenile: 4 | unallowed value juvenile: 4 | 31 | 380
6 | juvenile: 5 | unallowed value juvenile: 5 | 29 | 926
7 | Zangpost: 5 | unallowed value Zangpost: 5 | 24 | 7486
8 | Zangpost: 10 | unallowed value Zangpost: 10 | 15 | 10909
9 | Zangpost: 3 | unallowed value Zangpost: 3 | 15 | 7321
10 | juvenile: 6 | unallowed value juvenile: 6 | 13 | 940
| allowed_if_1 | adult, adult | juvenile | 46571 |
Value issue samples:
| Data value | Message | # Rows failed | First presence row index
--- | --- | --- | --- | ---
1 | juvenile: 1 | unallowed value juvenile: 1 | 112 | 64
2 | juvenile: 2 | unallowed value juvenile: 2 | 37 | 3748
3 | juvenile: 3 | unallowed value juvenile: 3 | 22 | 1078
4 | Zangpost: 1 | unallowed value Zangpost: 1 | 19 | 2475
5 | juvenile: 5 | unallowed value juvenile: 5 | 13 | 2559
6 | juvenile: 4 | unallowed value juvenile: 4 | 9 | 4889
7 | juvenile: 8 | unallowed value juvenile: 8 | 8 | 5594
8 | Zangpost: 3 | unallowed value Zangpost: 3 | 5 | 7321
9 | juvenile: 6 | unallowed value juvenile: 6 | 4 | 940
10 | juvenile: 12 | unallowed value juvenile: 12 | 3 | 6063
| delimitedvalues |  | 46834 |
| empty | True | 46834 |
| empty_if_1 | False | 37187 |
Value issue samples:
| Data value | Message | # Rows failed | First presence row index
--- | --- | --- | --- | ---
1 |  | empty values not allowed | 9647 | 18
| empty | False | 46834 |
| allowed | ICZN | 46834 |
| empty | False | 46834 |
| empty | False | 46834 |
| regex | INBO:NBN:[A-Z0-9]+ | 46834 |
| empty | True | 46834 |
| stringformat | json | 46834 |
| allowed | Orthoptera | 0 |
Value issue samples:
| Data value | Message | # Rows failed | First presence row index
--- | --- | --- | --- | ---
1 | Ortopthera | unallowed value Ortopthera | 46834 | 1
| empty | False | 46834 |
| allowed | abundant, numerous, scarce | 46834 |
| empty | True | 46834 |
| empty_if_1 | False | 46834 |
| allowed | abundance | 46834 |
| empty | True | 46834 |
| empty_if_1 | False | 46834 |
| allowed | Arthropoda | 46834 |
| empty | False | 46834 |
| delimitedvalues |  | 46834 |
| empty | True | 46834 |
| allowed | INBO | 46834 |
| empty | False | 46834 |
| empty | False | 46834 |
| empty | False | 46834 |
| allowed_delimitedvalue | male, female | 36924 |
Value issue samples:
| Data value | Message | # Rows failed | First presence row index
--- | --- | --- | --- | ---
1 | female: 1 | unallowed value female: 1 | 4126 | 21
2 | male: 1 | unallowed value male: 1 | 3601 | 19
3 | male: 2 | unallowed value male: 2 | 767 | 43
4 | female: 2 | unallowed value female: 2 | 575 | 19
5 | male: 3 | unallowed value male: 3 | 392 | 1084
6 | male: 5 | unallowed value male: 5 | 274 | 1083
7 | female: 3 | unallowed value female: 3 | 207 | 18
8 | male: 10 | unallowed value male: 10 | 158 | 1100
9 | male: 4 | unallowed value male: 4 | 151 | 1102
10 | female: 4 | unallowed value female: 4 | 122 | 28
| delimitedvalues |  | 46834 |
| empty | True | 46834 |
| allowed | Antwerp, East Flanders, Flemish Brabant, Limburg, West Flanders | 46834 |
| empty | True | 46834 |
| allowed | species | 46834 |
| empty | False | 46834 |
| allowed | Event, PhysicalObject, Sound, StillImage, Text | 0 |
Value issue samples:
| Data value | Message | # Rows failed | First presence row index
--- | --- | --- | --- | ---
1 | event | unallowed value event | 32484 | 4
2 | physicalObject | unallowed value physicalObject | 10025 | 1
3 | sound | unallowed value sound | 2195 | 681
4 | text | unallowed value text | 2127 | 524
5 | stillImage | unallowed value stillImage | 3 | 26085
| allowed_if_1 | Event, Sound, StillImage, Text | 44700 |
Value issue samples:
| Data value | Message | # Rows failed | First presence row index
--- | --- | --- | --- | ---
1 | text | unallowed value text | 2127 | 524
2 | sound | unallowed value sound | 4 | 4145
3 | event | unallowed value event | 3 | 35029
| allowed_if_2 | PhysicalObject | 46834 |
| empty | False | 46834 |
| empty_if_1 | False | 46834 |
| empty_if_2 | False | 46834 |
| allowed | UTM 1km, UTM 5km, Belgian Lambert 72 | 46834 |
| empty | True | 46834 |
| allowed_if_3 |  | 46834 |
| empty | True | 46834 |
| empty_if_1 | False | 46834 |
| empty_if_2 | False | 46834 |
| empty_if_3 | True | 46834 |
| regex_if_1 | 31U[D-G][S-T]\d\d\d\d | 46834 |
| regex_if_2 | 31U[D-G][S-T]\d\d[A-D] | 46834 |
| dateformat | %Y-%m-%d/%Y-%m-%d, %Y-%m/%Y-%m, %Y/%Y | 2080 |
Value issue samples:
| Data value | Message | # Rows failed | First presence row index
--- | --- | --- | --- | ---
1 | 1985 | string format of value '1985' not compliant with '['%Y-%m-%d/%Y-%m-%d', '%Y-%m/%Y-%m', '%Y/%Y']' | 575 | 3808
2 | 1999 | string format of value '1999' not compliant with '['%Y-%m-%d/%Y-%m-%d', '%Y-%m/%Y-%m', '%Y/%Y']' | 482 | 3077
3 | 2005-08-09 | string format of value '2005-08-09' not compliant with '['%Y-%m-%d/%Y-%m-%d', '%Y-%m/%Y-%m', '%Y/%Y']' | 372 | 704
4 | 2005-08-08 | string format of value '2005-08-08' not compliant with '['%Y-%m-%d/%Y-%m-%d', '%Y-%m/%Y-%m', '%Y/%Y']' | 300 | 2701
5 | 2005-08-13 | string format of value '2005-08-13' not compliant with '['%Y-%m-%d/%Y-%m-%d', '%Y-%m/%Y-%m', '%Y/%Y']' | 294 | 2693
6 | 2005-08-10 | string format of value '2005-08-10' not compliant with '['%Y-%m-%d/%Y-%m-%d', '%Y-%m/%Y-%m', '%Y/%Y']' | 287 | 724
7 | 1984-08 | string format of value '1984-08' not compliant with '['%Y-%m-%d/%Y-%m-%d', '%Y-%m/%Y-%m', '%Y/%Y']' | 222 | 3801
8 | 2006-08 | string format of value '2006-08' not compliant with '['%Y-%m-%d/%Y-%m-%d', '%Y-%m/%Y-%m', '%Y/%Y']' | 210 | 1279
9 | 2005-08 | string format of value '2005-08' not compliant with '['%Y-%m-%d/%Y-%m-%d', '%Y-%m/%Y-%m', '%Y/%Y']' | 207 | 460
10 | 2006-09-05 | string format of value '2006-09-05' not compliant with '['%Y-%m-%d/%Y-%m-%d', '%Y-%m/%Y-%m', '%Y/%Y']' | 205 | 2245
| empty | False | 46834 |
| allowed_if_2 |  | 46834 |
| empty | True | 46834 |
| empty_if_1 | False | 46834 |
| empty_if_2 | True | 46834 |
| max_if_1 | 246072 | 46834 |
| min_if_1 | 21829 | 46834 |
| numberformat_if_1 | x | 46834 |
| allowed_if_2 |  | 46834 |
| empty | True | 46834 |
| empty_if_1 | False | 46834 |
| empty_if_2 | True | 46834 |
| max_if_1 | 297889 | 46834 |
| min_if_1 | 22344 | 46834 |
| numberformat_if_1 | x | 46834 |
| allowed_if_1 | ED50 | 46834 |
| allowed_if_2 | Belgian Datum 1972 | 46834 |
| allowed_if_3 |  | 46834 |
| empty | True | 46834 |
| empty_if_1 | False | 46834 |
| empty_if_2 | False | 46834 |
| empty_if_3 | True | 46834 |
| empty | False | 46834 |